Learn R Programming

mcmcplots (version 0.2)

.graypr: Create a Gray Plotting Region

Description

This function colors the plotting region gray and plots light-gray gridlines. This function is intended for internal use only.

Usage

.graypr(x.axis = TRUE, y.axis = TRUE, x.major = TRUE, y.major = TRUE, x.minor = TRUE, y.minor=TRUE, x.malty = 1, y.malty = 1, x.milty = 1, y.milty = 1)

Arguments

x.axis
if TRUE an x axis will be plotted.
y.axis
if TRUE a y axis will be plotted.
x.major
if TRUE, major gridlines on the x axis will be plotted.
y.major
if TRUE, major gridlines on the y axis will be plotted.
x.minor
if TRUE, minor gridlines on the x axis will be plotted.
y.minor
if TRUE, minor gridlines on the y axis will be plotted.
x.malty
line type to be used on the x-axis, major gridlines.
y.malty
line type to be used on the y-axis, major gridlines.
x.milty
line type to be used on the x-axis, minor gridlines.
y.milty
line type to be used on the y-axis, minor gridlines.

Value

  • None.

Details

None.

References

None.

See Also

rect

Examples

Run this code
## None.

Run the code above in your browser using DataLab