as.mcmc.rjags: Convert an rjags Object to an mcmc or mcmc.list Object.
Description
This is a function to convert and object produced by the jags function in the R2jags package. If the rjags object contains more than one chain, then this function will return an mcmc.list object. Otherwise, the function returns an mcmc object.Usage
## S3 method for class 'rjags':
as.mcmc(x)
Value
- An
mcmc.list or mcmc object.