mcmcplotsPalette: Color Palette for the mcmcplots Package
Description
This function uses the colorspace package to create a color palette for the functions in the mcmcplots package.
Usage
mcmcplotsPalette(n, seq = FALSE)
Arguments
n
number of colors
seq
logical indicating whether to use "sequential" colors rather than "rainbow" colors
Value
A color palette of n colors.
Details
None.
References
Zeileis, A., Hornik, K. and Murrell, P. (2009) "Escaping RGBland: Selecting colors for statistical graphs." Compuational Statistics & Data Analysis, 53, 3259--3270.